@@ -1,22 +1,9 @@
-/*****************************************************************************
- * This file is part of Kiten, a KDE Japanese Reference Tool                 *
- * Copyright (C) 2006 Joseph Kerian <jkerian@gmail.com>                      *
- *                                                                           *
- * This library is free software; you can redistribute it and/or             *
- * modify it under the terms of the GNU Library General Public               *
- * License as published by the Free Software Foundation; either              *
- * version 2 of the License, or (at your option) any later version.          *
- *                                                                           *
- * This library is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
- * Library General Public License for more details.                          *
- *                                                                           *
- * You should have received a copy of the GNU Library General Public License *
- * along with this library; see the file COPYING.LIB.  If not, write to      *
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- * Boston, MA 02110-1301, USA.                                               *
- *****************************************************************************/
+/*
+    This file is part of Kiten, a KDE Japanese Reference Tool
+    SPDX-FileCopyrightText: 2006 Joseph Kerian <jkerian@gmail.com>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 /*
  *    Future Plans:
@@ -203,6 +190,7 @@ void RadSelectView::listPossibleKanji( const QList<Kanji>& list )
 
 void RadSelectView::loadKanji( QString &kanji )
 {
+  Q_UNUSED( kanji );
   //TODO: loadKanji method
 }
 
@@ -210,6 +198,9 @@ void RadSelectView::loadRadicals(  const QString &radicals
                                  , int strokeMin
                                  , int strokeMax )
 {
+  Q_UNUSED( radicals );
+  Q_UNUSED( strokeMin );
+  Q_UNUSED( strokeMax );
   //TODO: loadRadicals method
   emit searchModified();
 }
@@ -220,6 +211,8 @@ void RadSelectView::loadSettings()
   //Suggested options: Lookup in Kiten, Add to Search Bar, Copy to Clipboard
   selected_radicals->setFont( RadSelectConfigSkeleton::self()->resultListFont() );
   m_buttongrid->setFont( RadSelectConfigSkeleton::self()->font() );
+
+  m_buttongrid->setSortByFrequency( RadSelectConfigSkeleton::self()->sortByFrequency() );
 }
 
 void RadSelectView::strokeLimitChanged( int newvalue )
